==> wiki3_5_3.zip: wiki3_5_3/plugin/bugtrack/BugTrackHandler.pm <==
################################################################################
#
# Хȥåץ饰Υϥɥ顣
# 
################################################################################
package plugin::bugtrack::BugTrackHandler;
use strict;
#===============================================================================
# 󥹥ȥ饯
#===============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# ϥɥ
#==============================================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	my $cgi = $wiki->get_CGI;
	
	my $project  = $cgi->param("project");
	my $name     = $cgi->param("name");
	my $category = $cgi->param("category");
	my $priority = $cgi->param("priority");
	my $status   = $cgi->param("status");
	my $content  = $cgi->param("content");
	my $subject  = $cgi->param("subject");
	my $time     = time();
	
	if($name eq ""){
		return $wiki->error("̾ϤƤޤ");
	} elsif($subject eq ""){
		return $wiki->error("ޥ꤬ϤƤޤ");
	} elsif($content eq ""){
		return $wiki->error("ХƤϤƤޤ");
	}
	
	# post_nameȤǥå򥻥åȤ
	my $cookie = $cgi->cookie(-name=>'post_name',-value=>$name,-expires=>'+1M');
	print "Set-Cookie: ",$cookie->as_string,"\n";
	
	my $page = $self->make_pagename($wiki,$project);
	
	$content = "!!!$subject\n".
	           "*Ƽԡ $name\n".
	           "*ƥꡧ $category\n".
	           "*ͥ١ $priority\n".
	           "*֡ $status\n".
	           "* ".Util::format_date($time)."\n".
	           "{{bugstate}}\n".
	           "!!\n".$content."\n".
	           "!!\n{{comment}}";
	
	$wiki->save_page($page,$content);
	$wiki->redirect($page);
}

#==============================================================================
# ХݡȤΥڡ̾
#==============================================================================
sub make_pagename {
	my $self = shift;
	my $wiki = shift;
	my $project = shift;
	
	my @list = $wiki->get_page_list;
	my $count = 0;
	foreach(@list){
		if($_ =~ /^BugTrack-$project\/([0-9]+)$/){
			if($count < $1){
				$count = $1;
			}
		}
	}
	$count++;
	return "BugTrack-$project/$count";
}

1;

==> wiki3_5_6dev1.zip: wiki3_5_6dev1/plugin/bugtrack/BugTrackHandler.pm <==
################################################################################
#
# Хȥåץ饰Υϥɥ顣
# 
################################################################################
package plugin::bugtrack::BugTrackHandler;
use strict;
#===============================================================================
# 󥹥ȥ饯
#===============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# ϥɥ
#==============================================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	my $cgi = $wiki->get_CGI;
	
	my $project  = $cgi->param("project");
	my $name     = $cgi->param("name");
	my $category = $cgi->param("category");
	my $priority = $cgi->param("priority");
	my $status   = $cgi->param("status");
	my $content  = $cgi->param("content");
	my $subject  = $cgi->param("subject");
	my $time     = time();
	
	if($name eq ""){
		return $wiki->error("̾ϤƤޤ");
	} elsif($subject eq ""){
		return $wiki->error("ޥ꤬ϤƤޤ");
	} elsif($content eq ""){
		return $wiki->error("ХƤϤƤޤ");
	}
	
	# post_nameȤǥå򥻥åȤ
	my $cookie = $cgi->cookie(-name=>'post_name',-value=>$name,-expires=>'+1M');
	print "Set-Cookie: ",$cookie->as_string,"\n";
	
	# եޥåȥץ饰ؤб
	my $format = $wiki->get_edit_format();
	$name     = $wiki->convert_to_fswiki($name    ,$format,1);
	$category = $wiki->convert_to_fswiki($category,$format,1);
	$priority = $wiki->convert_to_fswiki($priority,$format,1);
	$status   = $wiki->convert_to_fswiki($status  ,$format,1);
	$content  = $wiki->convert_to_fswiki($content ,$format);
	
	my $page = $self->make_pagename($wiki,$project);
	
	$content = "!!!$subject\n".
	           "*Ƽԡ $name\n".
	           "*ƥꡧ $category\n".
	           "*ͥ١ $priority\n".
	           "*֡ $status\n".
	           "* ".Util::format_date($time)."\n".
	           "{{bugstate}}\n".
	           "!!\n".$content."\n".
	           "!!\n{{comment}}";
	
	$wiki->save_page($page,$content);
	$wiki->redirect($page);
}

#==============================================================================
# ХݡȤΥڡ̾
#==============================================================================
sub make_pagename {
	my $self = shift;
	my $wiki = shift;
	my $project = shift;
	
	my @list = $wiki->get_page_list;
	my $count = 0;
	foreach(@list){
		if($_ =~ /^BugTrack-$project\/([0-9]+)$/){
			if($count < $1){
				$count = $1;
			}
		}
	}
	$count++;
	return "BugTrack-$project/$count";
}

1;
